summaryrefslogtreecommitdiffstats
path: root/chrome/browser/browser.h
diff options
context:
space:
mode:
authorbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-04-18 19:52:40 +0000
committerbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-04-18 19:52:40 +0000
commit1ef5ad42064c8ef0d1503b68a7fbac01887ca093 (patch)
tree34a32b11a9db6f69fef27e7e81863d82a29bcd2d /chrome/browser/browser.h
parent59b49a66c3cd959fcf9d7b4bd9c6d88c70b39919 (diff)
downloadchromium_src-1ef5ad42064c8ef0d1503b68a7fbac01887ca093.zip
chromium_src-1ef5ad42064c8ef0d1503b68a7fbac01887ca093.tar.gz
chromium_src-1ef5ad42064c8ef0d1503b68a7fbac01887ca093.tar.bz2
Reverting 14005.
git-svn-id: svn://svn.chromium.org/chrome/trunk/src@14006 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/browser.h')
-rw-r--r--chrome/browser/browser.h27
1 files changed, 15 insertions, 12 deletions
diff --git a/chrome/browser/browser.h b/chrome/browser/browser.h
index d0f2d6f..af0fb52 100644
--- a/chrome/browser/browser.h
+++ b/chrome/browser/browser.h
@@ -227,13 +227,15 @@ class Browser : public TabStripModelDelegate,
PageTransition::Type type);
// Add a tab with its session history restored from the SessionRestore
- // system. If select is true, the tab is selected. |tab_index| gives the index
- // to insert the tab at. |selected_navigation| is the index of the
- // TabNavigation in |navigations| to select.
- TabContents* AddRestoredTab(const std::vector<TabNavigation>& navigations,
- int tab_index,
- int selected_navigation,
- bool select);
+ // system. If select is true, the tab is selected. Returns the created
+ // NavigationController. |tab_index| gives the index to insert the tab at.
+ // |selected_navigation| is the index of the TabNavigation in |navigations|
+ // to select.
+ NavigationController* AddRestoredTab(
+ const std::vector<TabNavigation>& navigations,
+ int tab_index,
+ int selected_navigation,
+ bool select);
// Replaces the state of the currently selected tab with the session
// history restored from the SessionRestore system.
@@ -523,10 +525,11 @@ class Browser : public TabStripModelDelegate,
void SyncHistoryWithTabs(int index);
// Called from AddRestoredTab and ReplaceRestoredTab to build a
- // TabContents from an incoming vector of TabNavigations.
- // Caller takes ownership of the returned TabContents.
- TabContents* BuildRestoredTab(const std::vector<TabNavigation>& navigations,
- int selected_navigation);
+ // NavigationController from an incoming vector of TabNavigations.
+ // Caller takes ownership of the returned NavigationController.
+ NavigationController* BuildRestoredNavigationController(
+ const std::vector<TabNavigation>& navigations,
+ int selected_navigation);
// OnBeforeUnload handling //////////////////////////////////////////////////
@@ -636,7 +639,7 @@ class Browser : public TabStripModelDelegate,
// toolbar during window creation (i.e. before any tabs have been added
// to the window).
TabContents* current_tab = browser_->GetSelectedTabContents();
- return current_tab ? &current_tab->controller() : NULL;
+ return current_tab ? current_tab->controller() : NULL;
}
private: